============
transpolibre
============
``transpolibre`` is a Python program to automate translation of ``gettext``
PO files using LibreTranslate.

.. toctree::
   about
   install
   usage
   libretranslate
   source
   languages
   todo
   license
   :maxdepth: 2
   :caption: Contents:
